@@ -163,6 +163,7 @@ class CategoryListView(View):
     Define a set of categories and have them availab ein the template with urls"""
     cats = ()
     opts = ()
+    orders = ()
     rss_view = None
 
     def get_queryset(self, **kwargs):
@@ -309,6 +310,7 @@ class CategoryListView(View):
             self.model.object = lambda self: self
 
         data['query'] = self.query
+        data['orders'] = self.get_orders()
         data['categories'] = self.get_cats()
         data.update(((cat.cid, cat.item) for cat in self.get_cats() if cat))
         data.update(self.get_value_opts())
@@ -318,6 +320,20 @@ class CategoryListView(View):
         data['clear_url'] = self.get_url(exclude='q')
         return data
 
+    def get_orders(self):
+        order = self.get_value('order')
+        for (o, label) in self.orders:
+            yield { 'id': o, 'name': label, 'down': '-' == order[0],
+                'active': order.strip('-') == o.strip('-'),
+                'url': self.get_url('order', reverse_order(o, o == order)) }
+
+def reverse_order(o, active=True):
+    if not active:
+        return o
+    if o[0] == '-':
+        return o[1:]
+    return '-' + o
+
 
 class CategoryFeed(Feed):
     """So these CategoryListViews can become Feeds we have to do a few bits for django"""
